## InformationFilter

### Introduction and Overview

This is a basic implementation of the information filter.

-------

## API Reference

::: bayesian_filters.kalman.information_filter.InformationFilter
